#include "tmpl.h"
#line 2 "fragments.tmpl"
/*
* Copyright (c) 2022 Omar Polo <op@omarpolo.com>
*
* Permission to use, copy, modify, and distribute this software for any
* purpose with or without fee is hereby granted, provided that the above
* copyright notice and this permission notice appear in all copies.
*
* THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
* WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
* ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
* WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
* ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#line 18 "fragments.tmpl"
#include <sys/queue.h>
#include <sys/tree.h>
#line 21 "fragments.tmpl"
#include <netinet/in.h>
#include <arpa/inet.h>
#line 24 "fragments.tmpl"
#include <event.h>
#include <limits.h>
#include <stdint.h>
#include <stdio.h>
#include <string.h>
#line 30 "fragments.tmpl"
#include "galileo.h"
#line 35 "fragments.tmpl"
int
tp_head(struct template *tp, const char *lang, const char *title)
{
int tp_ret = 0;
#line 37 "fragments.tmpl"
struct client *clt = tp->tp_arg;
struct proxy_config *pc = clt->clt_pc;
const char *stylesheet = pc ? pc->stylesheet : "";
const char *prfx = clt->clt_script_name;
const char *path = clt->clt_path_info;
#line 43 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "<!doctype html>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<html")) == -1) goto err;
#line 44 "fragments.tmpl"
if (*lang != '\0') {
#line 44 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, " ")) == -1)
goto err;
#line 44 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "lang=\"")) == -1) goto err;
#line 44 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, lang)) == -1)
goto err;
#line 44 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\"")) == -1) goto err;
}
#line 44 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, ">")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<head>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<meta name=\"viewport\" content=\"initial-scale=1\" />")) == -1) goto err;
#line 48 "fragments.tmpl"
if (*stylesheet == 0) {
if ((tp_ret = tp->tp_puts(tp, "<link rel=\"stylesheet\" href=\"")) == -1) goto err;
#line 49 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, prfx)) == -1)
goto err;
#line 49 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "galileo.css\" />")) == -1) goto err;
} else {
if ((tp_ret = tp->tp_puts(tp, "<link rel=\"stylesheet\" href=\"")) == -1) goto err;
#line 51 "fragments.tmpl"
if ((tp_ret = tp_urlescape(tp, stylesheet)) == -1)
goto err;
#line 51 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\" />")) == -1) goto err;
}
#line 54 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "<title>")) == -1) goto err;
if (title) {
if ((tp_ret = tp->tp_escape(tp, title)) == -1)
goto err;
} else if (pc) {
if ((tp_ret = tp->tp_puts(tp, "gemini://")) == -1) goto err;
#line 58 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, pc->proxy_name)) == -1)
goto err;
#line 58 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, path)) == -1)
goto err;
}
#line 60 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</title>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</head>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<body>")) == -1) goto err;
err:
return tp_ret;
}
#line 65 "fragments.tmpl"
int
tp_foot(struct template *tp)
{
int tp_ret = 0;
#line 67 "fragments.tmpl"
struct client *clt = tp->tp_arg;
struct proxy_config *pc = clt->clt_pc;
const char *path = clt->clt_path_info;
#line 71 "fragments.tmpl"
if (path == NULL)
path = "";
#line 74 "fragments.tmpl"
if (pc) {
if ((tp_ret = tp->tp_puts(tp, "<footer>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<hr />")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<dl>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<dt>Original URL:</dt>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<dd>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<a href=\"gemini://")) == -1) goto err;
#line 80 "fragments.tmpl"
if ((tp_ret = tp_urlescape(tp, pc->proxy_name)) == -1)
goto err;
#line 80 "fragments.tmpl"
if ((tp_ret = tp_urlescape(tp, path)) == -1)
goto err;
#line 80 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\">")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "gemini://")) == -1) goto err;
#line 81 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, pc->proxy_name)) == -1)
goto err;
#line 81 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, path)) == -1)
goto err;
if ((tp_ret = tp->tp_puts(tp, "</a>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</dd>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</dl>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</footer>")) == -1) goto err;
}
#line 87 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</body>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</html>")) == -1) goto err;
err:
return tp_ret;
}
#line 92 "fragments.tmpl"
int
tp_figure(struct template *tp, const char *url, const char *label)
{
int tp_ret = 0;
if ((tp_ret = tp->tp_puts(tp, "<figure>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<a href=\"")) == -1) goto err;
#line 94 "fragments.tmpl"
if ((tp_ret = tp_urlescape(tp, url)) == -1)
goto err;
#line 94 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\">")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<img src=\"")) == -1) goto err;
#line 95 "fragments.tmpl"
if ((tp_ret = tp_urlescape(tp, url)) == -1)
goto err;
#line 95 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\" />")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</a>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<figcaption>")) == -1) goto err;
if ((tp_ret = tp->tp_escape(tp, label)) == -1)
goto err;
if ((tp_ret = tp->tp_puts(tp, "</figcaption>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</figure>")) == -1) goto err;
err:
return tp_ret;
}
#line 103 "fragments.tmpl"
int
tp_pre_open(struct template *tp, const char *label)
{
int tp_ret = 0;
if ((tp_ret = tp->tp_puts(tp, "<figure>")) == -1) goto err;
if (label && *label != '\0') {
if ((tp_ret = tp->tp_puts(tp, "<figcaption>")) == -1) goto err;
#line 106 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, label)) == -1)
goto err;
#line 106 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</figcaption>")) == -1) goto err;
}
#line 108 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "<pre>")) == -1) goto err;
err:
return tp_ret;
}
#line 111 "fragments.tmpl"
int
tp_pre_close(struct template *tp)
{
int tp_ret = 0;
if ((tp_ret = tp->tp_puts(tp, "</pre>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</figure>")) == -1) goto err;
err:
return tp_ret;
}
#line 116 "fragments.tmpl"
int
tp_error(struct template *tp, int code, const char *reason)
{
int tp_ret = 0;
#line 118 "fragments.tmpl"
char scode[32];
int r;
#line 121 "fragments.tmpl"
r = snprintf(scode, sizeof(code), "%d", code);
if (r < 0 || (size_t)r >= sizeof(code))
return (0);
#line 126 "fragments.tmpl"
if ((tp_ret = tp_head(tp, "en", "Proxy error")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<main>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<h1>Proxy error</h1>")) == -1) goto err;
if (code != -1) {
if ((tp_ret = tp->tp_puts(tp, "<p>Request failed with code: <code>")) == -1) goto err;
#line 130 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, scode)) == -1)
goto err;
#line 130 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</code>.</p>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<p>The server says: ")) == -1) goto err;
#line 131 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, reason)) == -1)
goto err;
#line 131 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, ".</p>")) == -1) goto err;
} else {
if ((tp_ret = tp->tp_puts(tp, "<p>Unable to serve the page due to: ")) == -1) goto err;
#line 133 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, reason)) == -1)
goto err;
#line 133 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, ".</p>")) == -1) goto err;
}
#line 135 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</main>")) == -1) goto err;
if ((tp_ret = tp_foot(tp)) == -1) goto err;
err:
return tp_ret;
}
#line 139 "fragments.tmpl"
int
tp_inputpage(struct template *tp, const char *prompt)
{
int tp_ret = 0;
if ((tp_ret = tp_head(tp, "en", "input request")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<p>The server ask for input: <q>")) == -1) goto err;
#line 141 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, prompt)) == -1)
goto err;
#line 141 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</q>.</p>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<form method=\"post\" enctype=\"")) == -1) goto err;
#line 142 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, FORM_URLENCODED)) == -1)
goto err;
#line 142 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "\">")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<label for=\"reply\">")) == -1) goto err;
#line 143 "fragments.tmpl"
if ((tp_ret = tp->tp_escape(tp, "response ")) == -1)
goto err;
#line 143 "fragments.tmpl"
if ((tp_ret = tp->tp_puts(tp, "</label>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "<input type=\"text\" value=\"\" id=\"reply\" name=\"q\" autofocus />")) == -1) goto err;
if ((tp_ret = tp->tp_escape(tp, " ")) == -1)
goto err;
if ((tp_ret = tp->tp_puts(tp, "<button type=\"submit\">Submit!</button>")) == -1) goto err;
if ((tp_ret = tp->tp_puts(tp, "</form>")) == -1) goto err;
if ((tp_ret = tp_foot(tp)) == -1) goto err;
err:
return tp_ret;
}
